# SINTEF API

## How to run for development with Docker (Recommended)

> **Windows note**: Docker might not work with Windows 10 Home. Try using a Linux based distro or upgrade to Windows 10 Pro/Education/Enterprise

1. Make sure [Docker](https://docs.docker.com/desktop/) and [docker-compose](https://docs.docker.com/compose/install/) is installed and working on your system.

2. Create a `.env` file in the root directory with the following example contents for Docker development. Replace with your own credentials if necessary.
```
HOST=db
PORT=8086
USERNAME=root
PASSWORD=root
DATABASE=wow

CACHE_HOST=cache
CACHE_PORT=11211
```
3. Run `docker-compose up -d --build` to build and launch web API, cache, influxdb and Grafana containers.

`--build` flag can be omitted after first run unless changes are made to docker files or python dependencies.

Containers should now be accessible at:
- Web API: `localhost:5000`
- memcached: `localhost:11211`
- InfluxDB: `localhost:8086`
- Grafana: `localhost:3000`

API documentation is available at `localhost:5000/docs` or `localhost:5000/redoc`

### Stop containers
Use `docker-compose down` to stop running containers

### Grafana  
You can access Grafana to inspect data in the database by accessing `localhost:3000`. If you're prompted for credentials, enter standard credentials `admin/admin`.

If a data source is not already configured, you can configure it yourself with the following settings in `Configuration -> Data Sources -> Add data source`:
- HTTP
	- URL: `http://db:8086/`
	- Access: `Server(default)`
	- Basic auth: `On`
- Basic Auth Details
	- User: `root`
	- Password: `root`
- InfluxDB Details
	- Database: `wow`
	- User: `root`
	- Password: `root`
	- HTTP Method: `GET` (Optional)

## Run API outside of Docker (Not recommended)
1. Install InfluxDB and get it running on your computer.
2. Change the IP in `src/database/database_connector.py` to `localhost:8086` (Or desired IP).
3. Install python dependencies with Poetry `poetry install`.
4. Enter virtual environment with `poetry shell` OR run directly with `poetry run uvicorn --host 0.0.0.0 --port 5000 --root-path . src.app:app --reload`.
5. If you entered a new shell, use `uvicorn --host 0.0.0.0 --port 5000 --root-path . src.app:app --reload` to run the server locally outside of docker.

Web server should now be accessible from `localhost:5000`

## Importing test data
For development purposes, two endpoints for importing data found in `./netcdf` are available. See `localhost:5000/docs`.
These are not meant for production and are subject to change/removal at any time. Data is not included in repository.


### Who to contact?
Andreas Tolnes
<andrtoln@stud.ntnu.no>

Sebastian Aanesland Elvemo
<sebastel@stud.ntnu.no>